@@ -7,7 +7,6 @@ from __future__ import unicode_literals
 from Cheetah import five
 from Cheetah.filters import filters
 from Cheetah.NameMapper import NotFound, valueFromSearchList
-from Cheetah.Unspecified import Unspecified
 
 
 # pylint:disable=abstract-class-not-used
@@ -16,6 +15,7 @@ from Cheetah.Unspecified import Unspecified
 # Singleton object, representing no data to be written.
 # None or empty-string can be filtered into useful data, unlike NO_CONTENT.
 NO_CONTENT = object()
+UNSPECIFIED = object()
 
 
 class Template(object):
@@ -38,7 +38,7 @@ class Template(object):
       baseclasses.
 
       Instance attributes look like this:
-          self._CHEETAH__globalSetVars (_CHEETAH__xxx with 2 underscores)
+          self._CHEETAH__searchList (_CHEETAH__xxx with 2 underscores)
     """
 
     def __init__(
@@ -92,10 +92,8 @@ class Template(object):
                 'but got {0}'.format(type(searchList))
             )
 
-        self._CHEETAH__globalSetVars = {}
-
         # create our own searchList
-        self._CHEETAH__searchList = [self._CHEETAH__globalSetVars, self]
+        self._CHEETAH__searchList = [self]
         if searchList is not None:
             self._CHEETAH__searchList.extend(list(searchList))
 
@@ -108,15 +106,16 @@ class Template(object):
         """Return a reference to the searchlist"""
         return self._CHEETAH__searchList
 
-    def getVar(self, varName, default=Unspecified, autoCall=True, useDottedNotation=True):
+    def getVar(self, varName, default=UNSPECIFIED, autoCall=True, useDottedNotation=True):
         """Get a variable from the searchList.  If the variable can't be found
         in the searchList, it returns the default value if one was given, or
         raises NameMapper.NotFound.
         """
+        assert '$' not in varName, varName
         try:
-            return valueFromSearchList(self.searchList(), varName.replace('$', ''), autoCall, useDottedNotation)
+            return valueFromSearchList(self.searchList(), varName, autoCall, useDottedNotation)
         except NotFound:
-            if default is not Unspecified:
+            if default is not UNSPECIFIED:
                 return default
             else:
                 raise
@@ -124,7 +123,7 @@ class Template(object):
     def varExists(self, varName, autoCall=False, useDottedNotation=True):
         """Test if a variable name exists in the searchList."""
         try:
-            valueFromSearchList(self.searchList(), varName.replace('$', ''), autoCall, useDottedNotation)
+            valueFromSearchList(self.searchList(), varName, autoCall, useDottedNotation)
             return True
         except NotFound:
             return False
